using System;
using System.Data;
using System.Text.RegularExpressions;
using System.Web.UI.WebControls;

using CMS.FormEngine;
using CMS.Helpers;
using CMS.UIControls;
using CMS.Base.Web.UI;

public partial class CMSFormControls_Selectors_MultipleAlternativeFormSelection : DesignerPage
{
    protected void Page_Load(object sender, EventArgs e)
    {
        // Validate query params against hash value and check if control ID is not potential XSS threat
        string txtClientId = QueryHelper.GetString("txtelem", "");
        string lblClientId = QueryHelper.GetString("lblelem", "");
        Regex re = RegexHelper.GetRegex(@"[\w\d_$$]*");

        if (!QueryHelper.ValidateHash("hash") || !re.IsMatch(txtClientId) || !re.IsMatch(lblClientId))
        {
            pnlContent.Visible = false;
            return;
        }

        if (!RequestHelper.IsPostBack())
        {
            DataSet dsClasses = AlternativeFormInfoProvider.GetClassesWithAlternativeForms();

            drpClass.DataSource = dsClasses;
            drpClass.DataValueField = "FormClassID";
            drpClass.DataTextField = "ClassName";
            drpClass.DataBind();

            if (!DataHelper.DataSourceIsEmpty(dsClasses))
            {
                // Try to preselect class from drop-down list
                string className = QueryHelper.GetString("classname", string.Empty);
                if (className != string.Empty)
                {
                    drpClass.SelectedIndex = drpClass.Items.IndexOf(drpClass.Items.FindByText(className));
                }
                else
                {
                    drpClass.SelectedIndex = 0;
                }
                // Load alternative forms for selected class
                LoadAltFormsList(URLHelper.URLDecode(Request.Params["selected"]));
            }
        }

        SetSaveJavascript("SelectCurrentAlternativeForm('" + txtClientId + "','" + lblClientId + "'); return false;");

        PageTitle.TitleText = GetString("altforms.selectaltform");
        SetSaveResourceString("general.select");

        ltlScript.Text = ScriptHelper.GetScript("var lstAlternativeForms = document.getElementById('" + lstAlternativeForms.ClientID + "');");
        ltlScript.Text = ScriptHelper.GetScript("var selectedForms = document.getElementById('" + selectedForms.ClientID + "');");
    }

    /// <summary>
    /// Fills alternative form list according to selection in class CMSDropDownList.
    /// </summary>
    protected void LoadAltFormsList()
    {
        LoadAltFormsList(string.Empty);
    }

    /// <summary>
    /// Fills alternative form list according to selection in class CMSDropDownList.
    /// </summary>
    protected void LoadAltFormsList(string selected)
    {
        selected = string.IsNullOrWhiteSpace(selected) ? string.Empty : selected;
        int formClassId = ValidationHelper.GetInteger(drpClass.SelectedValue, 0);
        DataSet ds = AlternativeFormInfoProvider.GetAlternativeForms()
                            .Columns("FormName", "FormDisplayName", "FormClassID")
                            .WhereEquals("FormClassID", formClassId)
                            .OrderBy("FormName");

        lstAlternativeForms.Items.Clear();
        selectedForms.Items.Clear();

        if (!DataHelper.DataSourceIsEmpty(ds))
        {
            foreach (DataRow dr in ds.Tables[0].Rows)
            {
                AlternativeFormInfo afi = new AlternativeFormInfo(dr);
                if (afi != null)
                {
                    if ((afi.FormDisplayName != String.Empty) && (afi.FormName != String.Empty))
                    {
                        if (selected.IndexOf(afi.FullName) >= 0)
                            selectedForms.Items.Add(new ListItem(ResHelper.LocalizeString(afi.FormDisplayName), afi.FullName));
                        lstAlternativeForms.Items.Add(new ListItem(ResHelper.LocalizeString(afi.FormDisplayName), afi.FullName));
                    }
                }
            }
            lstAlternativeForms.SelectedValue = null;
            lstAlternativeForms.DataBind();
        }

        ds.Dispose();
    }


    protected void drpClass_SelectedIndexChanged(object sender, EventArgs e)
    {
        // Load alternative forms for selected class
        LoadAltFormsList();
    }

    protected void add_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        if (!string.IsNullOrWhiteSpace(lstAlternativeForms.SelectedValue))
        {
            bool add = true;
            foreach (ListItem li in selectedForms.Items)
                if (li.Value == lstAlternativeForms.SelectedValue)
                {
                    add = false;
                    break;
                }
            if (add)
            {
                ListItem li = new ListItem(lstAlternativeForms.SelectedItem.Text, lstAlternativeForms.SelectedItem.Value);
                selectedForms.Items.Add(li);
            }
        }
    }

    protected void up_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        if (selectedForms.SelectedIndex > 0)
        {
            int newIndex = selectedForms.SelectedIndex - 1;
            ListItem li = new ListItem(selectedForms.SelectedItem.Text, selectedForms.SelectedItem.Value);
            li.Selected = true;
            selectedForms.Items.Remove(selectedForms.SelectedItem);
            selectedForms.Items.Insert(newIndex, li);
        }
    }

    protected void down_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        if (selectedForms.SelectedIndex < selectedForms.Items.Count - 1)
        {
            int newIndex = selectedForms.SelectedIndex + 1;
            ListItem li = new ListItem(selectedForms.SelectedItem.Text, selectedForms.SelectedItem.Value);
            li.Selected = true;
            selectedForms.Items.Remove(selectedForms.SelectedItem);
            selectedForms.Items.Insert(newIndex, li);
        }
    }

    protected void delete_Click(object sender, System.Web.UI.ImageClickEventArgs e)
    {
        if (!string.IsNullOrWhiteSpace(selectedForms.SelectedValue))
        {
            selectedForms.Items.Remove(selectedForms.SelectedItem);
        }
    }
}